@@ -125,9 +125,13 @@ MassSpecTracePlotCompositeWidget::setupWidget()
   // pappso::MassSpecTracePlotWidget because the context that is passed as
   // argument is specific of that class.
   connect(static_cast<pappso::MassSpecTracePlotWidget *>(mp_plotWidget),
-          &pappso::MassSpecTracePlotWidget::keyPressEventSignal,
+          static_cast<void (pappso::MassSpecTracePlotWidget::*)(
+            const pappso::MassSpecTracePlotContext &)>(
+            &pappso::MassSpecTracePlotWidget::keyPressEventSignal),
           this,
-          &MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent);
+          static_cast<void (MassSpecTracePlotCompositeWidget::*)(
+            const pappso::MassSpecTracePlotContext &)>(
+            &MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent));
 
   connect(mp_plotWidget,
           &pappso::MassSpecTracePlotWidget::keyReleaseEventSignal,
@@ -337,7 +341,7 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
 
   N = local_maxima_trace.size();
 
-  //qDebug() << "The number of local maxima: " << N;
+  // qDebug() << "The number of local maxima: " << N;
 
   double *x     = new double[N];
   double *y     = new double[N];
@@ -634,7 +638,8 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
       m_ui.statusLineEdit->setText(
         "The Gaussian fit produced an empty trace. Plotting nothing.");
 
-      //qDebug() << "The Gaussian fit produced an empty trace. Plotting nothing.";
+      // qDebug() << "The Gaussian fit produced an empty trace. Plotting
+      // nothing.";
 
       return;
     }
@@ -695,7 +700,7 @@ void
 MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::MassSpecTracePlotContext &context)
 {
-  // qDebug().noquote() << "ENTER with massplotcontext:" << context.toString();
+   //qDebug().noquote() << "ENTER with massplotcontext:" << context.toString();
 
   // First call the base class that will fill-in the generic fields if the space
   // char was pressed.
@@ -1169,7 +1174,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
           m_newTraceHandlingMethod == NewTraceHandlingMethod::PLUS_COMBINE)
 
     {
-      //qDebug();
+      // qDebug();
 
       // Combination is requested. There are some situations:
 
@@ -1182,14 +1187,14 @@ MassSpecTracePlotCompositeWidget::addTrace(
 
       if(!dest_plottable_list.size())
         {
-          //qDebug() << "Adding trace but there is not a single trace available, "
-                      //"creating a new one.";
+          // qDebug() << "Adding trace but there is not a single trace
+          // available, " "creating a new one.";
 
           must_create_new_graph = true;
         }
       else
         {
-          //qDebug() << "Adding new trace with combination requested.";
+          // qDebug() << "Adding new trace with combination requested.";
 
           // Since we are asked that an integration to a mass spectrum be
           // performed, there must be a non-nullptr mz integration pointer in
@@ -1203,13 +1208,13 @@ MassSpecTracePlotCompositeWidget::addTrace(
               "integration "
               "params are not available in the processing flow.");
 
-          //qDebug() << "The most recent mz integration parameters:"
-                   //<< mz_integration_params_p->toString();
+          // qDebug() << "The most recent mz integration parameters:"
+          //<< mz_integration_params_p->toString();
 
           if(mz_integration_params_p->getBinningType() ==
              pappso::BinningType::NONE)
             {
-              //qDebug() << "Binning type none.";
+              // qDebug() << "Binning type none.";
 
               pappso::TraceMinusCombiner trace_minus_combiner;
               pappso::TracePlusCombiner trace_plus_combiner;
@@ -1411,8 +1416,8 @@ MassSpecTracePlotCompositeWidget::addTrace(
   // End of if(m_ui.keepTraceCombineNewPushButton->isChecked())
   else if(m_newTraceHandlingMethod == NewTraceHandlingMethod::REPLACE)
     {
-      //qDebug() << "Adding new trace by the replace method: removing the "
-                  //"current one(s).";
+      // qDebug() << "Adding new trace by the replace method: removing the "
+      //"current one(s).";
 
       // Start by erasing all the traces that are selected.
 
@@ -1429,7 +1434,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
     }
   else
     {
-      //qDebug();
+      // qDebug();
 
       // None of the button were checked, we simply created a new graph.
       must_create_new_graph = true;
@@ -1439,8 +1444,8 @@ MassSpecTracePlotCompositeWidget::addTrace(
     {
       // At this point we know we need to create a new trace.
 
-      //qDebug()
-        //<< "Adding a new trace: in fact we need to create one anew as is.";
+      // qDebug()
+      //<< "Adding a new trace: in fact we need to create one anew as is.";
 
       plottable_p = static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
                       ->addTrace(trace, local_color);
